@@ -35,11 +35,11 @@ extern "C" {
  *
  * Library version string
  */
-#define LIBFDISK_VERSION   "2.37.0"
+#define LIBFDISK_VERSION   "2.37.4"
 
 #define LIBFDISK_MAJOR_VERSION   2
 #define LIBFDISK_MINOR_VERSION   37
-#define LIBFDISK_PATCH_VERSION   0
+#define LIBFDISK_PATCH_VERSION   4
 
 /**
  * fdisk_context:
@@ -875,9 +875,12 @@ size_t fdisk_ask_menu_get_nitems(struct fdisk_ask *ask);
 int fdisk_ask_print_get_errno(struct fdisk_ask *ask);
 const char *fdisk_ask_print_get_mesg(struct fdisk_ask *ask);
 
-int fdisk_info(struct fdisk_context *cxt, const char *fmt, ...);
-int fdisk_warn(struct fdisk_context *cxt, const char *fmt, ...);
-int fdisk_warnx(struct fdisk_context *cxt, const char *fmt, ...);
+int fdisk_info(struct fdisk_context *cxt, const char *fmt, ...)
+			__attribute__ ((__format__ (__printf__, 2, 3)));
+int fdisk_warn(struct fdisk_context *cxt, const char *fmt, ...)
+			__attribute__ ((__format__ (__printf__, 2, 3)));
+int fdisk_warnx(struct fdisk_context *cxt, const char *fmt, ...)
+			__attribute__ ((__format__ (__printf__, 2, 3)));
 
 /* utils.h */
 extern char *fdisk_partname(const char *dev, size_t partno);
